# Mcdp #

A python wheel helps to build a Minecraft datapack.<br>
The name "Mcdp" is short for "Minecraft datapack".

[![License](https://img.shields.io/github/license/Ovizro/Mcdp.svg)](LICENSE)
[![PyPI](https://img.shields.io/pypi/v/Mcdp.svg)](https://pypi.python.org/pypi/Mcdp)
![Python Version](https://img.shields.io/badge/python-3.7+-blue.svg)

> Pay attention! This wheel is not full developed.

Language: English / [中文](https://github.com/Ovizro/Mcdp/blob/master/doc/zh_cn/README.md)